![](media/spice-net-logo-green-ai.png)

# SPICEnet in Python
SPICEnet is an artificial neural network that is capable of identifying the mathematical relationship between two values. This library provides a single core implementation for quick usage.
For more information about the network look up the pdf in the docs folder.

## Install
```pip install spicenet```

If you want to use the plotting subpackage use this command instead:\
```pip install spicenet[plotting]```

## How to use
Please take a look at the [tutorial notebook](/notebooks/spice_net_tutorial.ipynb).


## Notebooks
The Notebooks you will find in this repository, are examples on how to use this library.

- [tests](/notebooks/tests.ipynb): This notebook is only for test cases, it might not be running. 
- [solar panels](/notebooks/solar_panel_example.ipynb): This notebook shows you how to calculate the voltage of a solar panel by the lux level of the environment.
- [tutorial](/notebooks/spice_net_tutorial.ipynb): Follow this guid on how to use this library

